import pandas as pd
import mleakdetect as mld


def main() -> None:
    df = pd.read_csv("examples/Bitcoin 2024.csv")

    result = mld.analyze_dataset(
        df=df,
        split_mode="temporal",
        split_type="train_test",
        time_column="Date",
        id_columns=None,
        alpha=1.0,
        similarity_threshold=0.99,
        remove_exact_dups=True,
        remove_near_dups=False,
    )

    mld.print_leakage_report(result)
    mld.save_report_to_file(result, "leakage_report.md")
    print("Saved: leakage_report.md")


if __name__ == "__main__":
    main()
