"""
mleakdetect public API.

Users should be able to do:
    import mleakdetect as mld
    result = mld.analyze_dataset(...)
"""

from .core.analysis import analyze_dataset, LeakageAnalysisResult
from .core.report import print_leakage_report, save_report_to_file

__all__ = [
    "analyze_dataset",
    "LeakageAnalysisResult",
    "print_leakage_report",
    "save_report_to_file",
]
